==> zio-aws-chimesdkmediapipelines_2.13-5.17.252.1-sources.jar: zio/aws/chimesdkmediapipelines/model/package.scala <==
package zio.aws.chimesdkmediapipelines
import zio.prelude.Subtype
import zio.aws.chimesdkmediapipelines.model.primitives.{
  TagKey,
  ExternalUserIdType,
  GuidString
}
import java.time.Instant
import zio.aws.chimesdkmediapipelines.model.primitives.GuidString.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.chimesdkmediapipelines.model.primitives.AmazonResourceName.Type
    object Arn extends Subtype[String]
    type Arn = zio.aws.chimesdkmediapipelines.model.primitives.Arn.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.chimesdkmediapipelines.model.primitives.ClientRequestToken.Type
    object ExternalUserIdType extends Subtype[String]
    type ExternalUserIdType =
      zio.aws.chimesdkmediapipelines.model.primitives.ExternalUserIdType.Type
    object GuidString extends Subtype[String]
    type GuidString =
      zio.aws.chimesdkmediapipelines.model.primitives.GuidString.Type
    object Iso8601Timestamp extends Subtype[Instant]
    type Iso8601Timestamp =
      zio.aws.chimesdkmediapipelines.model.primitives.Iso8601Timestamp.Type
    object ResultMax extends Subtype[Int]
    type ResultMax =
      zio.aws.chimesdkmediapipelines.model.primitives.ResultMax.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.chimesdkmediapipelines.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue =
      zio.aws.chimesdkmediapipelines.model.primitives.TagValue.Type
  }
  type AttendeeIdList = List[GuidString]
  type ExternalUserIdList = List[ExternalUserIdType]
  type MediaCapturePipelineSummaryList =
    List[zio.aws.chimesdkmediapipelines.model.MediaCapturePipelineSummary]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.chimesdkmediapipelines.model.Tag]
}

==> zio-aws-chimesdkmediapipelines_2.13-5.20.17.2-sources.jar: zio/aws/chimesdkmediapipelines/model/package.scala <==
package zio.aws.chimesdkmediapipelines
import zio.prelude.Subtype
import zio.aws.chimesdkmediapipelines.model.primitives.{
  TagKey,
  ExternalUserIdType,
  GuidString
}
import java.time.Instant
import zio.aws.chimesdkmediapipelines.model.primitives.GuidString.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.chimesdkmediapipelines.model.primitives.AmazonResourceName.Type
    object Arn extends Subtype[String]
    type Arn = zio.aws.chimesdkmediapipelines.model.primitives.Arn.Type
    object AudioSampleRateOption extends Subtype[String]
    type AudioSampleRateOption =
      zio.aws.chimesdkmediapipelines.model.primitives.AudioSampleRateOption.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.chimesdkmediapipelines.model.primitives.ClientRequestToken.Type
    object ExternalUserIdType extends Subtype[String]
    type ExternalUserIdType =
      zio.aws.chimesdkmediapipelines.model.primitives.ExternalUserIdType.Type
    object GuidString extends Subtype[String]
    type GuidString =
      zio.aws.chimesdkmediapipelines.model.primitives.GuidString.Type
    object Iso8601Timestamp extends Subtype[Instant]
    type Iso8601Timestamp =
      zio.aws.chimesdkmediapipelines.model.primitives.Iso8601Timestamp.Type
    object ResultMax extends Subtype[Int]
    type ResultMax =
      zio.aws.chimesdkmediapipelines.model.primitives.ResultMax.Type
    object SensitiveString extends Subtype[String]
    type SensitiveString =
      zio.aws.chimesdkmediapipelines.model.primitives.SensitiveString.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.chimesdkmediapipelines.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue =
      zio.aws.chimesdkmediapipelines.model.primitives.TagValue.Type
  }
  type AttendeeIdList = List[GuidString]
  type ConcatenationSinkList =
    List[zio.aws.chimesdkmediapipelines.model.ConcatenationSink]
  type ConcatenationSourceList =
    List[zio.aws.chimesdkmediapipelines.model.ConcatenationSource]
  type ExternalUserIdList = List[ExternalUserIdType]
  type LiveConnectorSinkList =
    List[zio.aws.chimesdkmediapipelines.model.LiveConnectorSinkConfiguration]
  type LiveConnectorSourceList =
    List[zio.aws.chimesdkmediapipelines.model.LiveConnectorSourceConfiguration]
  type MediaCapturePipelineSummaryList =
    List[zio.aws.chimesdkmediapipelines.model.MediaCapturePipelineSummary]
  type MediaPipelineList =
    List[zio.aws.chimesdkmediapipelines.model.MediaPipelineSummary]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.chimesdkmediapipelines.model.Tag]
}
